@@ -18,7 +18,7 @@
 * 
 */
 
-#include "vulkancapsviewer.h"
+#include "vulkanCapsViewer.h"
 #include <QtWidgets/QApplication>
 #include <QDebug>
 #include <QCommandLineParser>
@@ -50,7 +50,7 @@ void logMessageHandler(QtMsgType type, const QMessageLogContext& context, const
     QFile logFile("log.txt");
     if (logFile.open(QIODevice::WriteOnly | QIODevice::Append)) {
         QTextStream textStream(&logFile);
-        textStream << logMessage << endl;
+        textStream << logMessage << Qt::endl;
     };
     // Suppress compiler warning
     (void)context;
@@ -58,8 +58,9 @@ void logMessageHandler(QtMsgType type, const QMessageLogContext& context, const
 
 int main(int argc, char *argv[])
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
-    QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+#ifdef Q_OS_WIN
+    // Disable dark mode on Winodows
+    qputenv("QT_QPA_PLATFORM", "windows::darkmode=0");
 #endif
 
     QApplication application(argc, argv);
