@@ -28,9 +28,9 @@ class settingsDialog : public QDialog
 private:
 	Settings appSettings;
 public:
-    settingsDialog(Settings appSet);
+    settingsDialog(QWidget *parent, Settings appSet);
 	~settingsDialog();
 private Q_SLOTS:
 	void slotAccept();
 	void slotCancel();
-};
\ No newline at end of file
+};
