@@ -3,8 +3,8 @@
 /*
  *
  * Vulkan hardware capability viewer
- * 
- * Copyright (C) 2016-2023 by Sascha Willems (www.saschawillems.de)
+ *
+ * Copyright (C) 2016-2025 by Sascha Willems (www.saschawillems.de)
  *
  * This code is free software, you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -21,7 +21,7 @@
  */
 
  /*
-  * Generator for creating the VulkanDeviceInfoExtensions.h/.cpp source files used by the caps viewer to fetch device extensions
+  * Generator for creating the vulkanDeviceInfoExtensions.h/.cpp source files used by the caps viewer to fetch device extensions
   */
 
  class TypeContainer
@@ -118,16 +118,16 @@ class ExtensionContainer
     function __construct($xml, $typecontainer)
     {
         foreach ($xml->extensions->extension as $ext_node) {
-            // Skip Vulkan SC only extensions
-            if ($ext_node['supported'] == 'vulkansc') {
+            // Skip Vulkan SC only and disabled extensions
+            if (($ext_node['supported'] == 'vulkansc') || ($ext_node['supported'] == 'disabled')) {
                 continue;
             }
             $features2_node = null;
             $properties2_node = null;
-            // We're only interested in extensions with property or feature types                
+            // We're only interested in extensions with property or feature types
             foreach ($ext_node->require as $require) {
                 foreach ($require as $requirement) {
-                    if (strcasecmp($requirement->getName, 'type')) {
+                    if (strcasecmp($requirement->getName(), 'type') !== false) {
                         $ft2 = $typecontainer->getFeatures2Type((string)$requirement['name']);
                         if (!$features2_node && $ft2) {
                             $features2_node = $ft2;
@@ -167,7 +167,7 @@ class CppBuilder
         $sType = TypeContainer::getsType($extension->features2);
         $res = "\tif (extensionSupported(\"{$extension->name}\")) {\n";
         $res .= "\t\tconst char* extension(\"{$extension->name}\");\n";
-        $res .= "\t\t{$extension->features2['name']}* extFeatures = new {$extension->features2['name']}{};\n";        
+        $res .= "\t\t{$extension->features2['name']}* extFeatures = new {$extension->features2['name']}{};\n";
         $res .= "\t\textFeatures->sType = $sType;\n";
         $res .= "\t\tdeviceFeatures2 = initDeviceFeatures2(extFeatures);\n";
         $res .= "\t\tvulkanContext.vkGetPhysicalDeviceFeatures2KHR(device, &deviceFeatures2);\n";
@@ -180,7 +180,7 @@ class CppBuilder
             $name = (string)$member->name;
             $res .= "\t\tpushFeature2(extension, \"$name\", extFeatures->$name);\n";
         }
-        $res .= "\t\tdelete extFeatures;\n";        
+        $res .= "\t\tdelete extFeatures;\n";
         $res .= "\t}\n";
         return $res;
     }
@@ -225,7 +225,7 @@ class CppBuilder
                             $enum_dim = 16;
                             break;
                         case 'VK_LUID_SIZE':
-                        case 'VK_LUID_SIZE_HR':
+                        case 'VK_LUID_SIZE_KHR':
                             $enum_dim = 8;
                             break;
                     }
@@ -268,7 +268,7 @@ class CppBuilder
                 $res .= "\t\tpushProperty2(extension, \"$name\", QVariant::fromValue(QVariantList({ $qlist })));\n";
             }
         }
-        $res .= "\t\tdelete extProps;\n";        
+        $res .= "\t\tdelete extProps;\n";
         $res .= "\t}\n";
         return $res;
     }
@@ -280,27 +280,27 @@ class CppBuilder
 
     public function writeHeader(string $file_name, string $output_dir)
     {
-        if (!file_exists('templates/VulkanDeviceInfoExtensions.h')) {
+        if (!file_exists('templates/vulkanDeviceInfoExtensions.h')) {
             echo "Template $file_name does not exist!\n";
             return;
         }
-        $header_source = file_get_contents('templates/VulkanDeviceInfoExtensions.h');
+        $header_source = file_get_contents('templates/vulkanDeviceInfoExtensions.h');
         $header_replace = '';
         foreach ($this->header_functions as $header_func) {
             $header_replace .= "    void $header_func();\n";
         }
         $header_source = str_replace('{{header_functions}}', $header_replace, $header_source);
         $header_source = str_replace('{{VK_HEADER_VERSION}}', $this->vk_header_version, $header_source);
-        file_put_contents("$output_dir/VulkanDeviceInfoExtensions.h", $header_source);
+        file_put_contents("$output_dir/vulkanDeviceInfoExtensions.h", $header_source);
     }
 
     public function writeImplementation(string $file_name, string $output_dir, $extension_container)
     {
-        if (!file_exists('templates/VulkanDeviceInfoExtensions.cpp')) {
+        if (!file_exists('templates/vulkanDeviceInfoExtensions.cpp')) {
             echo "Template $file_name does not exist!\n";
             return;
         }
-        $impl_source = file_get_contents('templates/VulkanDeviceInfoExtensions.cpp');
+        $impl_source = file_get_contents('templates/vulkanDeviceInfoExtensions.cpp');
 
         $fn_calls = array_map(function ($fn) {
             return "    " . $fn . "();";
@@ -333,18 +333,21 @@ class CppBuilder
                 return ($ext->group == $ext_group && $ext->features2);
             });
             if (count($ext_arr) > 0) {
-                $cpp_features_block .= "void VulkanDeviceInfoExtensions::readPhysicalFeatures_$ext_group() {\n";
+                $cpp_features_block .= "void vulkanDeviceInfoExtensions::readPhysicalFeatures_$ext_group() {\n";
                 $cpp_features_block .= "\tVkPhysicalDeviceFeatures2 deviceFeatures2{};\n";
                 if ($ext_group == 'QNX') {
                     $cpp_features_block .= "#if defined(VK_USE_PLATFORM_SCREEN_QNX)\n";
                 }
                 if ($ext_group == 'ANDROID') {
-                    $cpp_features_block .= "#if defined(VK_USE_PLATFORM_ANDROID)\n";
-                }                
+                    $cpp_features_block .= "#if defined(VK_USE_PLATFORM_ANDROID_KHR)\n";
+                }
+                if ($ext_group == 'OHOS') {
+                    $cpp_features_block .= "#if defined(VK_USE_PLATFORM_OHOS)\n";
+                }
                 foreach ($ext_arr as $extension) {
                     $cpp_features_block .= $this->generateFeatures2CodeBlock($extension);
                 }
-                if (in_array($ext_group, ['QNX', 'ANDROID']) != false) {
+                if (in_array($ext_group, ['QNX', 'ANDROID', 'OHOS']) != false) {
                     $cpp_features_block .= "#endif\n";
                 }
                 $cpp_features_block .= "}\n";
@@ -354,20 +357,23 @@ class CppBuilder
                 return ($ext->group == $ext_group && $ext->properties2);
             });
             if (count($ext_arr) > 0) {
-                $cpp_properties_block .= "void VulkanDeviceInfoExtensions::readPhysicalProperties_$ext_group() {\n";
+                $cpp_properties_block .= "void vulkanDeviceInfoExtensions::readPhysicalProperties_$ext_group() {\n";
                 $cpp_properties_block .= "\tVkPhysicalDeviceProperties2 deviceProps2{};\n";
                 if ($ext_group == 'QNX') {
                     $cpp_properties_block .= "#if defined(VK_USE_PLATFORM_SCREEN_QNX)\n";
                 }
                 if ($ext_group == 'ANDROID') {
-                    $cpp_properties_block .= "#if defined(VK_USE_PLATFORM_ANDROID)\n";
-                }                    
+                    $cpp_properties_block .= "#if defined(VK_USE_PLATFORM_ANDROID_KHR)\n";
+                }
+                if ($ext_group == 'OHOS') {
+                    $cpp_properties_block .= "#if defined(VK_USE_PLATFORM_OHOS)\n";
+                }
                 foreach ($ext_arr as $extension) {
                     $cpp_properties_block .= $this->generateProperties2CodeBlock($extension);
                 }
-                if (in_array($ext_group, ['QNX', 'ANDROID']) != false) {
+                if (in_array($ext_group, ['QNX', 'ANDROID', 'OHOS']) != false) {
                     $cpp_properties_block .= "#endif\n";
-                }                
+                }
                 $cpp_properties_block .= "}\n";
             }
         }
@@ -379,7 +385,7 @@ class CppBuilder
             $impl_source = str_replace('{{implementation_properties2_functions}}', $cpp_properties_block, $impl_source);
         }
 
-        file_put_contents("$output_dir/VulkanDeviceInfoExtensions.cpp", $impl_source);
+        file_put_contents("$output_dir/vulkanDeviceInfoExtensions.cpp", $impl_source);
     }
 }
 
@@ -391,7 +397,7 @@ $output_dir = "..\\";
 if (!is_dir($output_dir)) {
     mkdir($output_dir);
 }
-if (file_exists($output_dir."VulkanDeviceInfoExtensions.cpp")) {
+if (file_exists($output_dir."vulkanDeviceInfoExtensions.cpp")) {
     echo "Warning: Output files will be overwritten\n";
 }
 
@@ -427,22 +433,22 @@ foreach ($ext_groups as $ext_group) {
         $cpp_builder->addHeaderFunction("readPhysicalProperties_$ext_group");
     }
 }
-$cpp_builder->writeHeader("$output_dir/VulkanDeviceInfoExtensions.h", $output_dir);
-$cpp_builder->writeImplementation("$output_dir/VulkanDeviceInfoExtensions.cpp", $output_dir, $extension_container);
+$cpp_builder->writeHeader("$output_dir/vulkanDeviceInfoExtensions.h", $output_dir);
+$cpp_builder->writeImplementation("$output_dir/vulkanDeviceInfoExtensions.cpp", $output_dir, $extension_container);
 
 // Output extension list for changelog
-$extenstion_list_file = $output_dir . "/extensionlist.txt";
-if (file_exists($extenstion_list_file)) {
-    unlink($extenstion_list_file);
+$extension_list_file = $output_dir . "/extensionlist.txt";
+if (file_exists($extension_list_file)) {
+    unlink($extension_list_file);
 }
 foreach ($ext_groups as $ext_group) {
     $ext_arr = array_filter($extension_container->extensions, function ($ext) use ($ext_group) {
         return ($ext->group == $ext_group && ($ext->features2 || $ext->properties2));
     });
     if (count($ext_arr) > 0) {
-        file_put_contents($extenstion_list_file, "$ext_group\n", FILE_APPEND);
+        file_put_contents($extension_list_file, "$ext_group\n", FILE_APPEND);
         foreach ($ext_arr as $ext) {
-            file_put_contents($extenstion_list_file, "$ext->name\n", FILE_APPEND);
+            file_put_contents($extension_list_file, "$ext->name\n", FILE_APPEND);
         }
     }
 }
